import { env } from '$env/dynamic/private';
import { csrf } from '$lib/server/csrf';
import { DB } from '$lib/server/drizzle';
import { runSeeds } from '$lib/server/drizzle/seeds';
import { JWT } from '$lib/server/jwt';
import { sequence } from '@sveltejs/kit/hooks';
import { migrate } from 'drizzle-orm/mysql2/migrator';
import { handleSession } from 'svelte-kit-cookie-session';

const { AUTO_MIGRATE, SESSION_SECRET, SESSION_SECURE } = env;

await DB.init();
await JWT.init();

if (AUTO_MIGRATE === 'true') {
	await migrate(DB.drizzle, { migrationsFolder: './migrations' });
}

await runSeeds();

export const handle = sequence(
	csrf(['/oauth2/token', '/oauth2/introspect', '/oauth2/device_authorization']),
	handleSession({
		secret: SESSION_SECRET,
		cookie: {
			secure: SESSION_SECURE === 'true'
		}
	})
);
