export class ApiUtils {
	static redirect(url: string, status = 302): Response {
		return new Response(null, {
			status,
			headers: {
				Location: url
			}
		});
	}

	static async getJsonOrFormBody(request: Request) {
		if (request.headers.get('content-type')?.startsWith('application/json')) {
			try {
				const jsonBody = await request.json();
				return jsonBody;
			} catch {
				return {};
			}
		}

		try {
			const formBody = await request.formData();
			return Object.fromEntries(formBody);
		} catch (err) {
			return {};
		}
	}
}
