import { json, text, type Handle } from '@sveltejs/kit';

const isContentType = (request: Request, ...types: string[]) => {
	const type = request.headers.get('content-type')?.split(';', 1)[0].trim() ?? '';
	return types.includes(type);
};

const isFormContentType = (request: Request) =>
	isContentType(request, 'application/x-www-form-urlencoded', 'multipart/form-data');

/**
 * CSRF protection copied from sveltekit but with the ability to turn it off for specific routes.
 */
export const csrf =
	(allowedPaths: string[]): Handle =>
	async ({ event, resolve }) => {
		const forbidden =
			event.request.method === 'POST' &&
			event.request.headers.get('origin') !== event.url.origin &&
			isFormContentType(event.request) &&
			!allowedPaths.includes(event.url.pathname);

		if (forbidden) {
			const csrfError = `Cross-site ${event.request.method} form submissions are forbidden`;
			if (event.request.headers.get('accept') === 'application/json') {
				return json({ error: 'forbidden', error_description: csrfError }, { status: 403 });
			}

			return text(csrfError, { status: 403 });
		}

		return resolve(event);
	};
