import { eq } from 'drizzle-orm';
import { DB, privilege } from '..';

/**
 * System privileges which must always exist in the database.
 */
const privileges = [
	'admin',
	'admin:user',
	'admin:user:privilege',
	'admin:oauth2',
	'admin:audit',
	'admin:document',
	'self:oauth2',
	'self:oauth2:implicit',
	'self:oauth2:create'
];

export default async function privilegesSeed() {
	for (const priv of privileges) {
		const [exists] = await DB.drizzle
			.select({ id: privilege.id })
			.from(privilege)
			.where(eq(privilege.name, priv));
		if (exists) continue;
		await DB.drizzle.insert(privilege).values({ name: priv });
	}
}
