import { env } from '$env/dynamic/private';
import nodemailer from 'nodemailer';
import type { EmailTemplate } from './template.interface';

const {
	EMAIL_ENABLED,
	EMAIL_FROM,
	EMAIL_SMTP_HOST,
	EMAIL_SMTP_PASS,
	EMAIL_SMTP_PORT,
	EMAIL_SMTP_SECURE,
	EMAIL_SMTP_USER
} = env;

export class Emails {
	public transport?: nodemailer.Transporter;
	public static from = EMAIL_FROM;

	static sender: Emails;

	static getSender() {
		if (!Emails.sender) {
			Emails.sender = new Emails();
		}
		return Emails.sender;
	}

	constructor() {
		this.createTransport();
	}

	public async send(
		to: string,
		subject: string,
		text: string,
		html?: string,
		from = Emails.from
	): Promise<unknown> {
		return this.transport?.sendMail({
			to,
			subject,
			text,
			html,
			from
		});
	}

	public async sendTemplate(to: string, subject: string, message: EmailTemplate): Promise<unknown> {
		return this.send(to, subject, message.text, message.html);
	}

	protected createTransport() {
		if (EMAIL_ENABLED !== 'true') return;
		this.transport = nodemailer.createTransport({
			host: EMAIL_SMTP_HOST,
			port: Number(EMAIL_SMTP_PORT) || undefined,
			secure: EMAIL_SMTP_SECURE === 'true',
			auth: {
				user: EMAIL_SMTP_USER,
				pass: EMAIL_SMTP_PASS
			}
		});
	}
}

export * from './templates';
