import type { OAuth2Client } from '$lib/server/drizzle';
import { InvalidScope, ServerError } from '../../error';
import { OAuth2AccessTokens, OAuth2Clients, OAuth2Tokens } from '../../model';
import type { OAuth2TokenResponse } from '../../response';

/**
 * Issue client access token
 * @param client - Client
 * @param wantScope - Requested scopes
 * @returns Access token
 */
export async function clientCredentials(
	client: OAuth2Client,
	wantScope: string | string[]
): Promise<OAuth2TokenResponse> {
	let scope: string[] = [];

	const resObj: OAuth2TokenResponse = {
		token_type: 'bearer'
	};

	scope = OAuth2Clients.transformScope(wantScope);
	if (!OAuth2Clients.checkScope(client, scope)) {
		throw new InvalidScope('Client does not allow access to this scope');
	}

	// console.debug('Scope check passed', scope);

	try {
		resObj.access_token = await OAuth2AccessTokens.create(
			null,
			client.client_id,
			scope,
			OAuth2Tokens.tokenTtl
		);
	} catch (err) {
		throw new ServerError('Failed to call accessToken.create function');
	}

	resObj.expires_in = OAuth2Tokens.tokenTtl;

	return resObj;
}
