import { authenticator as totp } from 'otplib';
import { DB, userToken, type User } from '../drizzle';
import { and, eq, gt, isNull, or } from 'drizzle-orm';
import { env } from '$env/dynamic/public';

totp.options = {
	window: 2
};

export class TimeOTP {
	public static validate(secret: string, token: string): boolean {
		return totp.verify({ token, secret });
	}

	public static getUri(secret: string, username: string): string {
		return totp.keyuri(username, PUBLIC_SITE_NAME, secret);
	}

	public static createSecret(): string {
		return totp.generateSecret();
	}

	public static async isUserOtp(subject: PartialK<User, 'password'>) {
		const tokens = await DB.drizzle
			.select({ id: userToken.id })
			.from(userToken)
			.where(
				and(
					eq(userToken.type, 'totp'),
					eq(userToken.userId, subject.id),
					or(isNull(userToken.expires_at), gt(userToken.expires_at, new Date()))
				)
			);
		return !!tokens?.length;
	}

	public static async getUserOtp(subject: User) {
		const [token] = await DB.drizzle
			.select({ id: userToken.id, token: userToken.token })
			.from(userToken)
			.where(
				and(
					eq(userToken.type, 'totp'),
					eq(userToken.userId, subject.id),
					or(isNull(userToken.expires_at), gt(userToken.expires_at, new Date()))
				)
			)
			.limit(1);
		return token;
	}

	public static async saveUserOtp(subject: User, secret: string) {
		await DB.drizzle.insert(userToken).values({
			type: 'totp',
			token: secret,
			userId: subject.id
		});
	}
}
