import { browser } from '$app/environment';
import { onMount } from 'svelte';
import { writable } from 'svelte/store';

export type ThemeModeType = 'light' | 'dark';

export const themeMode = writable<ThemeModeType>('light', (set) => {
	if (!browser) return;
	const storageMode = window?.localStorage.getItem('inThemeMode') as ThemeModeType;
	const uaTheme = window?.matchMedia?.('(prefers-color-scheme: dark)');
	const uaMode: ThemeModeType = uaTheme?.matches ? 'dark' : 'light';

	set(storageMode || uaMode || 'light');

	const uaThemeCallback = () => set(uaTheme?.matches ? 'dark' : 'light');
	uaTheme?.addEventListener('change', uaThemeCallback);
	return () => uaTheme?.removeEventListener('change', uaThemeCallback);
});

export const useThemeMode = () =>
	onMount(() =>
		themeMode.subscribe((value) => document.documentElement.setAttribute('theme-base', value))
	);

export const setThemeMode = (mode: ThemeModeType) => {
	if (!browser) return;
	themeMode.set(mode);
	window.localStorage.setItem('inThemeMode', mode);
};
