import { ApiUtils } from '$lib/server/api-utils.js';
import { OAuth2Clients } from '$lib/server/oauth2/index.js';
import { UserTokens, Users } from '$lib/server/users';

export const GET = async ({ locals, url }) => {
	const currentUser = await Users.getBySession(locals.session.data?.user);
	if (!currentUser) {
		await locals.session.destroy();
		return ApiUtils.redirect(`/login?redirectTo=${encodeURIComponent(url.pathname)}`);
	}

	const token = url.searchParams.get('token');
	if (!token) {
		return ApiUtils.redirect('/');
	}

	const fetch = await UserTokens.getByToken(token, 'invite');
	if (!fetch?.userId || !fetch.metadata?.startsWith('clientmanager=')) {
		return ApiUtils.redirect('/');
	}

	const inviter = await Users.getById(fetch.userId);
	if (!inviter) {
		return ApiUtils.redirect('/');
	}

	const [, clientId] = fetch.metadata.split('=');
	const client = await OAuth2Clients.fetchById(clientId);
	if (!client) {
		return ApiUtils.redirect('/');
	}

	await OAuth2Clients.addManager(client, inviter, currentUser);
	await UserTokens.remove(fetch);

	return ApiUtils.redirect(`/ssoadmin/oauth2/${client.client_id}`);
};
