import { OAuth2Clients, OAuth2Users } from '$lib/server/oauth2/index.js';
import { Users } from '$lib/server/users';
import { fail, redirect } from '@sveltejs/kit';

interface MappedClient {
	id: string;
	title: string;
	description: string | null;
	scope: string[];
	website?: string;
}

export const actions = {
	revoke: async ({ locals, url }) => {
		const currentUser = await Users.getBySession(locals.session.data?.user);
		if (!currentUser) {
			await locals.session.destroy();
			return redirect(301, `/login?redirectTo=${encodeURIComponent(url.pathname)}`);
		}

		const clientId = url.searchParams.get('client') as string;
		if (!clientId) {
			return fail(400, { invalid: true });
		}

		await OAuth2Users.revokeConsent(currentUser, clientId);

		return {};
	}
};

export const load = async ({ locals, url }) => {
	const currentUser = await Users.getBySession(locals.session.data?.user);
	if (!currentUser) {
		await locals.session.destroy();
		return redirect(301, `/login?redirectTo=${encodeURIComponent(url.pathname)}`);
	}

	const entites = await OAuth2Users.listAuthorizations(currentUser);
	const items = entites.reduce<MappedClient[]>((accum, entry) => {
		const existing = accum.find((item) => item.id === entry.o_auth2_client.client_id);
		if (existing) {
			if (!existing.website && entry.o_auth2_client_url?.type === 'website') {
				existing.website = entry.o_auth2_client_url.url;
			}

			return accum;
		}

		accum.push({
			id: entry.o_auth2_client.client_id,
			title: entry.o_auth2_client.title,
			description: entry.o_auth2_client.description,
			scope: OAuth2Clients.splitScope(entry.o_auth2_client_authorization.scope || ''),
			website:
				entry.o_auth2_client_url?.type === 'website' ? entry.o_auth2_client_url.url : undefined
		});

		return accum;
	}, []);

	return { items };
};
