import { OAuth2AuthorizationController } from '$lib/server/oauth2/controller/authorization.js';
import { OAuth2Error } from '$lib/server/oauth2/error.js';
import { OAuth2Response } from '$lib/server/oauth2/response.js';
import { Users } from '$lib/server/users';
import { fail } from '@sveltejs/kit';

export const actions = {
	default: async ({ request, locals, url }) => {
		locals.user = await Users.readSessionOrRedirect(locals, url);

		try {
			return await OAuth2AuthorizationController.actionRequest({ request, locals, url });
		} catch (err) {
			if (err instanceof OAuth2Error) {
				const obj = OAuth2Response.errorPlain(
					url,
					err,
					url.searchParams.get('redirect_uri') || undefined
				);
				return fail(err.status, obj);
			}

			throw err;
		}
	}
};

export const load = async ({ locals, url }) => {
	locals.user = await Users.readSessionOrRedirect(locals, url);

	try {
		return await OAuth2AuthorizationController.getRequest({ locals, url });
	} catch (err) {
		if (err instanceof OAuth2Error) {
			return OAuth2Response.errorPlain(url, err, url.searchParams.get('redirect_uri') || undefined);
		}

		throw err;
	}
};
