import { OAuth2Error } from '$lib/server/oauth2/error.js';
import { OAuth2Response } from '$lib/server/oauth2/response.js';
import { OAuth2DeviceAuthorizationController } from '$lib/server/oauth2/controller/device-authorization.js';
import { RateLimiter } from 'sveltekit-rate-limiter/server';
import { error } from '@sveltejs/kit';

const limiter = new RateLimiter({
	IP: [6, 'm']
});

export const POST = async (event) => {
	const { request, url } = event;
	if (await limiter.isLimited(event)) error(429, "You're doing that too much!");

	try {
		return await OAuth2DeviceAuthorizationController.postRequest({ request });
	} catch (error) {
		if (error instanceof OAuth2Error) {
			return OAuth2Response.error(url, error);
		}
		throw error;
	}
};
