import { OAuth2Error, SlowDown } from '$lib/server/oauth2/error.js';
import { OAuth2Response } from '$lib/server/oauth2/response.js';
import { OAuth2TokenController } from '$lib/server/oauth2/controller/token.js';
import { RateLimiter } from 'sveltekit-rate-limiter/server';

const limiter = new RateLimiter({
	IP: [15, 'm']
});

export const POST = async (event) => {
	const { request, url } = event;

	try {
		if (await limiter.isLimited(event)) {
			throw new SlowDown('Please, slow down!');
		}

		return await OAuth2TokenController.postHandler({ request, url });
	} catch (error) {
		if (error instanceof OAuth2Error) {
			return OAuth2Response.error(url, error);
		}
		throw error;
	}
};
