import { AdminUtils } from '$lib/server/admin-utils';
import type { User } from '$lib/server/drizzle/schema.js';
import { OAuth2Clients } from '$lib/server/oauth2/index.js';
import { Users } from '$lib/server/users';
import { hasPrivileges } from '$lib/utils.js';

const PAGE_SIZE = 20;

export const load = async ({ parent, url }) => {
	const { user } = await parent();
	const currentUser = await Users.getBySession(user);
	AdminUtils.checkPrivileges(user, [['admin:oauth2', 'self:oauth2']]);

	let limit = PAGE_SIZE;
	let page = 1;
	let filter: string | undefined = undefined;
	if (url.searchParams.has('page')) {
		page = Number(url.searchParams.get('page')) || 1;
	}

	if (url.searchParams.has('pageSize')) {
		limit = Number(url.searchParams.get('pageSize')) || PAGE_SIZE;
	}

	if (url.searchParams.has('filter')) {
		filter = url.searchParams.get('filter') as string;
	}

	const offset = (page - 1) * limit;
	const fullPrivileges = hasPrivileges(user.privileges, ['admin:oauth2']);
	const createPrivileges = hasPrivileges(user.privileges, [['admin:oauth2', 'self:oauth2:create']]);

	const data = await OAuth2Clients.getClientByAdminUser(currentUser as User, {
		filter,
		limit,
		offset,
		omitSecret: true,
		listAll: fullPrivileges
	});

	return {
		fullPrivileges,
		createPrivileges,
		...data
	};
};
