import { AdminUtils } from '$lib/server/admin-utils';
import { Changesets } from '$lib/server/changesets.js';
import { OAuth2Clients } from '$lib/server/oauth2/index.js';
import { fail, redirect } from '@sveltejs/kit';

interface CreateClientRequest {
	title: string;
	description: string;
	redirectUri: string;
}

export const actions = {
	default: async ({ locals, request }) => {
		const { currentUser } = await AdminUtils.getActionUser(locals, [
			['admin:oauth2', 'self:oauth2:create']
		]);

		const body = await request.formData();
		const { title, description, redirectUri } = Changesets.take<CreateClientRequest>(
			['title', 'description', 'redirectUri'],
			body
		);

		if (!title || title.length < 3 || title.length > 32) {
			return fail(400, { errors: ['invalidTitle'] });
		}

		if (description && description.length > 1000) {
			return fail(400, { errors: ['invalidDescription'] });
		}

		if (!redirectUri) {
			return fail(400, { errors: ['noRedirect'] });
		}

		const uuid = await OAuth2Clients.createClient(currentUser, title, redirectUri, description);

		return redirect(303, `/ssoadmin/oauth2/${uuid}`);
	}
};

export const load = async ({ parent }) => {
	const { user } = await parent();
	AdminUtils.checkPrivileges(user, [['admin:oauth2', 'self:oauth2:create']]);

	return {};
};
