import { AdminUtils } from '$lib/server/admin-utils.js';
import { UsersAdmin } from '$lib/server/users/admin.js';

const PAGE_SIZE = 20;

export const load = async ({ parent, url }) => {
	const { user } = await parent();
	AdminUtils.checkPrivileges(user, ['admin:user']);

	let limit = PAGE_SIZE;
	let page = 1;
	let filter: string | undefined = undefined;
	if (url.searchParams.has('page')) {
		page = Number(url.searchParams.get('page')) || 1;
	}

	if (url.searchParams.has('pageSize')) {
		limit = Number(url.searchParams.get('pageSize')) || PAGE_SIZE;
	}

	if (url.searchParams.has('filter')) {
		filter = url.searchParams.get('filter') as string;
	}

	const offset = (page - 1) * limit;

	return await UsersAdmin.getAllUsers({ filter, limit, offset });
};
